@@ -85,12 +85,14 @@ class Server(object):
         if not isinstance(logger, bool):
             self.logger = logger
         else:
-            logging.basicConfig()
             self.logger = logging.getLogger('socketio')
-            if logger:
-                self.logger.setLevel(logging.INFO)
-            else:
-                self.logger.setLevel(logging.ERROR)
+            if not logging.root.handlers and \
+                    self.logger.level == logging.NOTSET:
+                if logger:
+                    self.logger.setLevel(logging.INFO)
+                else:
+                    self.logger.setLevel(logging.ERROR)
+                self.logger.addHandler(logging.StreamHandler())
 
     def on(self, event, handler=None, namespace=None):
         """Register an event handler.
